var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { ID_GATEWAY_EIP_712_TYPES, ID_GATEWAY_ADDRESS, } from "@farcaster/hub-nodejs";
import { EVMContractAddress, FarcasterIdGatewayContractError, } from "@snickerdoodlelabs/objects";
import { injectable } from "inversify";
import { ResultAsync } from "neverthrow";
import { BaseContract } from "../../implementations/BaseContract.js";
import { ContractsAbis } from "../../interfaces/objects/index.js";
let FarcasterIdGatewayContract = class FarcasterIdGatewayContract extends BaseContract {
    constructor(providerOrSigner) {
        super(providerOrSigner, EVMContractAddress(ID_GATEWAY_ADDRESS), ContractsAbis.FarcasterIdGatewayAbi.abi);
        this.providerOrSigner = providerOrSigner;
    }
    price(extraStorage) {
        // If extraStorage was provided, call price with it, otherwise call without
        // https://optimistic.etherscan.io/address/0x00000000fc25870c6ed6b6c7e41fb078b7656f69#code#F2#L64
        return ResultAsync.fromPromise(extraStorage != undefined
            ? this.contract.price(extraStorage)
            : this.contract.price(), (e) => {
            return this.generateError(e, "Unable to call price()");
        });
    }
    nonces(address) {
        return ResultAsync.fromPromise(this.contract.nonces(address), (e) => {
            return this.generateError(e, "Unable to call nonces()");
        });
    }
    register(recoveryAddress, overrides) {
        return this.assureSigner("register").andThen(() => {
            return this.writeToContract("register", [recoveryAddress], overrides);
        });
    }
    registerWithExtraStorage(recoveryAddress, extraStorage, overrides) {
        return this.assureSigner("register").andThen(() => {
            return this.writeToContract("register", [recoveryAddress, extraStorage], overrides);
        });
    }
    // Called by Admin EW to register for on behalf of a user's EW
    registerFor(ownerAddress, recoveryAddress, deadline, signature, // EIP-712 'Register' signature from fidOwner obtained from getRegisterSignature()
    overrides) {
        return this.assureSigner("registerFor").andThen(() => {
            return this.price().andThen((registerPrice) => {
                // If there overrides provided, update its value to registerPrice.
                // If no override passed, create a new one ContractOverrides and update its value with registerPrice.
                const overridesToUpdate = overrides
                    ? overrides
                    : {};
                overridesToUpdate.value = registerPrice;
                return this.writeToContract("registerFor", [ownerAddress, recoveryAddress, deadline, signature], overridesToUpdate);
            });
        });
    }
    // Called by Admin EW to register for on behalf of a user's EW
    registerForWithExtraStorage(ownerAddress, recoveryAddress, deadline, signature, // EIP-712 'Register' signature from fidOwner obtained from getRegisterSignature()
    extraStorage, overrides) {
        return this.assureSigner("registerFor").andThen(() => {
            return this.price(extraStorage).andThen((registerPrice) => {
                // If overrides provided, update its value to registerPrice.
                // If no override passed, create a new ContractOverrides and update its value with registerPrice.
                const overridesToUpdate = overrides
                    ? overrides
                    : {};
                overridesToUpdate.value = registerPrice;
                return this.writeToContract("registerFor", [ownerAddress, recoveryAddress, deadline, signature, extraStorage], overrides);
            });
        });
    }
    // Called by the owner's EW to sign a 'Register' signature
    getRegisterSignature(ownerAddress, recoveryAddress, nonce, deadline) {
        return this.assureSigner("getRegisterSignature").andThen((signer) => {
            // message should be RegistrationParams struct
            //    https://docs.farcaster.xyz/reference/contracts/reference/id-gateway#register-signature
            //    Needs to be a EIP712 signature
            const message = {
                to: ownerAddress,
                recovery: recoveryAddress,
                nonce: nonce,
                deadline: deadline,
            };
            return ResultAsync.fromPromise(signer.signTypedData(ID_GATEWAY_EIP_712_TYPES.domain, this.removeReadonlyFromReadonlyTypes(ID_GATEWAY_EIP_712_TYPES.types), message), (e) => {
                return e;
            });
        });
    }
    removeReadonlyFromReadonlyTypes(obj) {
        return obj;
    }
    generateContractSpecificError(msg, e, transaction) {
        return new FarcasterIdGatewayContractError(msg, e, transaction);
    }
};
FarcasterIdGatewayContract = __decorate([
    injectable(),
    __metadata("design:paramtypes", [Object])
], FarcasterIdGatewayContract);
export { FarcasterIdGatewayContract };
//# sourceMappingURL=FarcasterIdGatewayContract.js.map